Module detection

Module detection 

Storm cell detection algorithms. Storm cell detection algorithms.

This module provides algorithms for identifying and characterizing storm cells in radar data using connected-component analysis on reflectivity fields.

Structs

StormCell
A detected storm cell identified by connected-component analysis on a reflectivity sweep field.
StormCellBounds
Geographic bounding box of a storm cell.
StormCellDetector
Detects storm cells in a reflectivity sweep field using connected-component labeling.