Module filter

Module filter 

Filtering algorithms for sweep field data. Filtering algorithms for sweep field data.

Filters transform a SweepField by modifying gate values or statuses based on various criteria such as value thresholds, spatial patterns, or cross-product relationships.

Structs

CorrelationCoefficientFilter
Correlation coefficient-based clutter removal.
GaussianSmooth
Gaussian smoothing filter in polar coordinates.
MedianFilter
Median filter in an azimuth x range kernel.
ThresholdFilter
Masks gates whose values fall outside a specified range.