Filtering algorithms for sweep field data. Filtering algorithms for sweep field data.
Filters transform a SweepField by modifying gate values
or statuses based on various criteria such as value thresholds, spatial patterns, or
cross-product relationships.
Structs
- Correlation
Coefficient Filter - Correlation coefficient-based clutter removal.
- Gaussian
Smooth - Gaussian smoothing filter in polar coordinates.
- Median
Filter - Median filter in an azimuth x range kernel.
- Threshold
Filter - Masks gates whose values fall outside a specified range.